@@ -1,5 +1,5 @@
 from django.core.checks import register, Warning
-from django.db import OperationalError
+from django.db.utils import OperationalError
 
 
 @register()
@@ -17,7 +17,7 @@ def example_check(app_configs, **kwargs):
             ))
     except OperationalError:
             errors.append(Warning(
-                'The bank user does not exist',
+                'Presumably non existent database',
                 hint="create a database for the application",
                 id='talerbank.E002'
             ))
